Validation study of AeroSandbox `AeroBuildup` as applied to low-aspect-ratio (AR) wings, especially those with significant vortex lift.

Data from:

- E.C. Polhamus. A concept of the vortex lift of sharp-edge delta wings based on a leading-edge-suction
  analogy. Technical Note D-3767, NASA, Dec 1966.
  
  - Figure 12.
